@@ -50,6 +50,9 @@ $sql = "
 		`mysql_password` varchar(30) default NULL,
 		`odbc_func` varchar(100) default NULL,
 		`odbc_query` text,
+		`url_query` text,
+		`agi_query` text,
+                `agi_var_name_res` varchar(255), 
                 `enable_dtmf_input` varchar(8), 
                 `timeout` INT, 
                 `announcement_id` INT(11),
@@ -154,5 +157,23 @@ if(DB::IsError($check)) {
         if(DB::IsError($result)) { die_freepbx($result->getDebugInfo()); }
 }
 
+$sql = "SELECT agi_query FROM dynroute";
+$check = $db->getRow($sql, DB_FETCHMODE_ASSOC);
+if(DB::IsError($check)) {
+        // add new field
+        $sql = "ALTER TABLE dynroute ADD COLUMN `agi_query` TEXT;";
+        $result = $db->query($sql);
+        if(DB::IsError($result)) { die_freepbx($result->getDebugInfo()); }
+}
+
+$sql = "SELECT agi_var_name_res FROM dynroute";
+$check = $db->getRow($sql, DB_FETCHMODE_ASSOC);
+if(DB::IsError($check)) {
+        // add new field
+        $sql = "ALTER TABLE dynroute ADD COLUMN `agi_var_name_res` VARCHAR(255);";
+        $result = $db->query($sql);
+        if(DB::IsError($result)) { die_freepbx($result->getDebugInfo()); }
+}
+
 dynroute_init();
 
