@@ -192,6 +192,7 @@ function dynroute_show_edit($id, $nbroptions, $post) {
                                 <option value="mysql" <?php echo ($dynroute_details['sourcetype'] == 'mysql' ? 'selected' : '')?>>MySQL</option>
                                 <option value="odbc" <?php echo ($dynroute_details['sourcetype'] == 'odbc' ? 'selected' : '')?>>ODBC</option>
                                 <option value="url" <?php echo ($dynroute_details['sourcetype'] == 'url' ? 'selected' : '')?>>URL</option>
+                                <option value="agi" <?php echo ($dynroute_details['sourcetype'] == 'agi' ? 'selected' : '')?>>AGI</option>
                         </select>
 			</td>
 		</tr>
@@ -210,6 +211,24 @@ function dynroute_show_edit($id, $nbroptions, $post) {
 			</td>
 		</tr>
 
+		<tr>
+	               <td colspan="2">
+                       <div id="agi" <?php if ($dynroute_details['sourcetype'] != 'agi') echo 'style="display: none"';?>>
+                                <table cellpadding="2" cellspacing="0" width="100%">
+                                        <tr><td colspan="2"><h5><?php echo _("AGI") ?><hr></h5></div></td></tr>
+                                        <tr>
+                                                <td><a href="#" class="info"><?php echo _("AGI script and parameters")?><span><?php echo _("Name of the AGI script. Optional parameters may be appended using the , as separator")?></span></a></td>
+                                                <td><input type="text" name="agi_query" size="50" value="<?php echo (isset($dynroute_details['agi_query']) ? htmlentities($dynroute_details['agi_query']) : ''); ?>" tabindex="<?php echo ++$tabindex;?>"></td>
+                                        <tr>
+                                        </tr>
+                                                <td><a href="#" class="info"><?php echo _("Result variable")?><span><?php echo _("The name of the variable in the script which must be set with the result. See test.agi for an example.")?></span></a></td>
+                                                <td><input type="text" name="agi_var_name_res" value="<?php echo (isset($dynroute_details['agi_var_name_res']) ? htmlentities($dynroute_details['agi_var_name_res']) : ''); ?>" tabindex="<?php echo ++$tabindex;?>"></td>
+                                        </tr>
+				</table>
+			</div>
+			</td>
+		</tr>
+
 		<tr>
 	               <td colspan="2">
                        <div id="odbc" <?php if ($dynroute_details['sourcetype'] != 'odbc') echo 'style="display: none"';?>>
@@ -382,14 +401,22 @@ function displaySourceParameters(sourcetypeSelect, key) {
 	if (sourcetypeSelect.options[key].value == 'url') {
                 document.getElementById('url').style.display = '';
                 document.getElementById('odbc').style.display = 'none';
+                document.getElementById('agi').style.display = 'none';
+                document.getElementById('mysql').style.display = 'none';
+        } else if (sourcetypeSelect.options[key].value == 'agi') {
+                document.getElementById('url').style.display = 'none';
+                document.getElementById('odbc').style.display = 'none';
+                document.getElementById('agi').style.display = '';
                 document.getElementById('mysql').style.display = 'none';
         } else if (sourcetypeSelect.options[key].value == 'odbc') {
                 document.getElementById('url').style.display = 'none';
                 document.getElementById('odbc').style.display = '';
+                document.getElementById('agi').style.display = 'none';
                 document.getElementById('mysql').style.display = 'none';
         } else if (sourcetypeSelect.options[key].value == 'mysql') {
                 document.getElementById('url').style.display = 'none';
                 document.getElementById('odbc').style.display = 'none';
+                document.getElementById('agi').style.display = 'none';
                 document.getElementById('mysql').style.display = '';
         }
 }
